@@ -4,6 +4,12 @@ from typing import Any, Dict, Iterable, List, Optional, Set, Tuple, Type, Union
 
 from optimade.models.entries import EntryResource
 
+# A number that approximately tracks the number of types with mappers
+# so that the global caches can be set to the correct size.
+# See https://github.com/Materials-Consortia/optimade-python-tools/issues/1434
+# for the details.
+NUM_ENTRY_TYPES = 4
+
 __all__ = ("BaseResourceMapper",)
 
 
@@ -27,8 +33,7 @@ class classproperty(property):
 
 
 class BaseResourceMapper:
-    """
-    Generic Resource Mapper that defines and performs the mapping
+    """Generic Resource Mapper that defines and performs the mapping
     between objects in the database and the resource objects defined by
     the specification.
 
@@ -71,7 +76,7 @@ class BaseResourceMapper:
     TOP_LEVEL_NON_ATTRIBUTES_FIELDS: Set[str] = {"id", "type", "relationships", "links"}
 
     @classmethod
-    @lru_cache(maxsize=1)
+    @lru_cache(maxsize=NUM_ENTRY_TYPES)
     def all_aliases(cls) -> Iterable[Tuple[str, str]]:
         """Returns all of the associated aliases for this entry type,
         including those defined by the server config. The first member
@@ -147,7 +152,7 @@ class BaseResourceMapper:
         return retrieve_queryable_properties(cls.ENTRY_RESOURCE_CLASS.schema())
 
     @classproperty
-    @lru_cache(maxsize=1)
+    @lru_cache(maxsize=NUM_ENTRY_TYPES)
     def ENDPOINT(cls) -> str:
         """Returns the expected endpoint for this mapper, corresponding
         to the `type` property of the resource class.
@@ -161,7 +166,7 @@ class BaseResourceMapper:
         )
 
     @classmethod
-    @lru_cache(maxsize=1)
+    @lru_cache(maxsize=NUM_ENTRY_TYPES)
     def all_length_aliases(cls) -> Tuple[Tuple[str, str], ...]:
         """Returns all of the associated length aliases for this class,
         including those defined by the server config.
@@ -300,7 +305,7 @@ class BaseResourceMapper:
         return cls.get_optimade_field(field)
 
     @classmethod
-    @lru_cache(maxsize=1)
+    @lru_cache(maxsize=NUM_ENTRY_TYPES)
     def get_required_fields(cls) -> set:
         """Get REQUIRED response fields.
 
